@@ -2,4 +2,4 @@ import Test.Hspec
 import qualified YesodCoreTest
 
 main :: IO ()
-main = hspecX $ descriptions $ YesodCoreTest.specs
+main = hspec YesodCoreTest.specs
